@@ -10,7 +10,12 @@ hermite.he.polynomials <- function( n, normalized=FALSE )
 ### normalized = a boolean value.  if true, the polynomials are normalized
 ###
     recurrences <- hermite.he.recurrences( n, normalized )
-    polynomials <- orthogonal.polynomials( recurrences )
+    if ( normalized ) {
+        h.0 <- sqrt( 2 * pi )
+        p.0 <- polynomial( c( 1 / sqrt( h.0 ) ) )
+        polynomials <- orthonormal.polynomials( recurrences, p.0 )
+    }
+    else
+        polynomials <- orthogonal.polynomials( recurrences )
     return( polynomials )
-    return( NULL )
 }
